const { name, port } = require('./package')

const path = require('path')
function resolve (dir) {
  return path.join(__dirname, dir)
}
module.exports = {
  // publicPath: dev ? `//localhost:${port}` : '/workorder',
  publicPath: '/pure',
  lintOnSave: true,
  devServer: {
    hot: true,
    disableHostCheck: true,
    port,
    overlay: {
      warnings: false,
      errors: true
    },
    headers: {
      'Access-Control-Allow-Origin': '*'
    }
  },
  chainWebpack: (config) => {
    config.module
      .rule('svg')
      .exclude.add(resolve('src/icons'))
      .end()

    config.module
      .rule('icons')
      .test(/\.svg$/)
      .include.add(resolve('src/icons'))
      .end()
      .use('svg-sprite-loader')
      .loader('svg-sprite-loader')
      .options({
        symbolId: 'icon-[name]'
      })
  },
  configureWebpack: {
    resolve: {
      alias: {
        '@': resolve('src'),
        '@img': resolve('src/assets/images'),
        '@icon': resolve('src/assets/icons'),
        '@style': resolve('src/assets/styles'),
        '@comp': resolve('src/components'),
        '@conf': resolve('src/config')
      }
    },
    output: {
      library: `${name}-[name]`,
      libraryTarget: 'umd', // 把微应用打包成 umd 库格式
      jsonpFunction: `webpackJsonp_${name}`
    }
  }
}
